@@ -11,7 +11,13 @@ class BarCodeFilter(InputFilter):
 
     def queryset(self, request, queryset):
 
-        if not self.value():
+        value = self.value()
+
+        if not value:
             return
 
-        return queryset.filter(bar_code=self.value())
+        # Fix for old barcodes
+        if value.startswith('000') and len(value) == 12:
+            value = value[:-1]
+
+        return queryset.filter(bar_code__icontains=value)
