@@ -7,7 +7,7 @@ from apps.products.models import Product
 
 def validate_barcode(bar_code, exclude_id=None):
 
-    queryset = Product.objects.filter(bar_code=bar_code)
+    queryset = Product.objects.active().filter(bar_code=bar_code)
 
     if exclude_id:
         queryset = queryset.exclude(pk=exclude_id)
